pub struct InitEventCtx {
pub event: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for InitEventCtx.
Fields
event: Pubkeypayer: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitEventCtxwhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitEventCtxwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for InitEventCtx
impl ToAccountMetas for InitEventCtx
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitEventCtx
impl RefUnwindSafe for InitEventCtx
impl Send for InitEventCtx
impl Sync for InitEventCtx
impl Unpin for InitEventCtx
impl UnsafeUnpin for InitEventCtx
impl UnwindSafe for InitEventCtx