pub struct Event {Show 13 fields
pub bump: u8,
pub authority: Pubkey,
pub scan_count: u32,
pub scan_bank: u32,
pub allow_creators: Vec<Pubkey>,
pub allow_collections: Vec<Pubkey>,
pub allow_mints: bool,
pub allow_addresses: bool,
pub payment_mint: Option<Pubkey>,
pub payment_amount: Option<u64>,
pub start_time: Option<i64>,
pub end_time: Option<i64>,
pub name: String,
}Fields
bump: u8scan_count: u32scan_bank: u32allow_creators: Vec<Pubkey>allow_collections: Vec<Pubkey>allow_mints: boolallow_addresses: boolpayment_mint: Option<Pubkey>payment_amount: Option<u64>start_time: Option<i64>end_time: Option<i64>name: StringTrait Implementations
Sourceimpl AccountDeserialize for Event
impl AccountDeserialize for Event
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Event
impl AccountSerialize for Event
Sourceimpl BorshDeserialize for Event
impl BorshDeserialize for Event
Sourceimpl BorshSerialize for Eventwhere
u8: BorshSerialize,
Pubkey: BorshSerialize,
u32: BorshSerialize,
Vec<Pubkey>: BorshSerialize,
bool: BorshSerialize,
Option<Pubkey>: BorshSerialize,
Option<u64>: BorshSerialize,
Option<i64>: BorshSerialize,
String: BorshSerialize,
impl BorshSerialize for Eventwhere
u8: BorshSerialize,
Pubkey: BorshSerialize,
u32: BorshSerialize,
Vec<Pubkey>: BorshSerialize,
bool: BorshSerialize,
Option<Pubkey>: BorshSerialize,
Option<u64>: BorshSerialize,
Option<i64>: BorshSerialize,
String: BorshSerialize,
Sourceimpl Discriminator for Event
impl Discriminator for Event
fn discriminator() -> [u8; 8]