pub struct EventEntry {
pub bump: u8,
pub event: Pubkey,
pub mint: Pubkey,
pub user: Pubkey,
pub last_used_timestamp: i64,
pub delegated: bool,
}Fields
bump: u8event: Pubkeymint: Pubkeyuser: Pubkeylast_used_timestamp: i64delegated: boolTrait Implementations
Sourceimpl AccountDeserialize for EventEntry
impl AccountDeserialize for EventEntry
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for EventEntry
impl AccountSerialize for EventEntry
Sourceimpl BorshDeserialize for EventEntrywhere
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
i64: BorshDeserialize,
bool: BorshDeserialize,
impl BorshDeserialize for EventEntrywhere
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
i64: BorshDeserialize,
bool: BorshDeserialize,
Sourceimpl BorshSerialize for EventEntry
impl BorshSerialize for EventEntry
Sourceimpl Clone for EventEntry
impl Clone for EventEntry
Sourcefn clone(&self) -> EventEntry
fn clone(&self) -> EventEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Discriminator for EventEntry
impl Discriminator for EventEntry
fn discriminator() -> [u8; 8]